vregistry.py
changeset 2381 caad2367d940
parent 2302 e0393451e9a5
parent 2308 b478c3a8ad2a
child 2476 1294a6bdf3bf
--- a/vregistry.py	Wed Jul 15 09:45:13 2009 +0200
+++ b/vregistry.py	Thu Jul 16 13:30:13 2009 +0200
@@ -1,10 +1,10 @@
 """
-* the vregistry handle various type of objects interacting
-  together. The vregistry handle registration of dynamically loaded
-  objects and provide a convenient api access to those objects
+* the vregistry handles various types of objects interacting
+  together. The vregistry handles registration of dynamically loaded
+  objects and provides a convenient api to access those objects
   according to a context
 
-* to interact with the vregistry, object should inherit from the
+* to interact with the vregistry, objects should inherit from the
   VObject abstract class
 
 * the selection procedure has been generalized by delegating to a